************************************************************************************************
************************************************************************************************
*
* EXPLORE THE DETERMINANTS OF POPULARITY IN THE DATA
* -- Popularity is a segment-level measure coming out of model
*
************************************************************************************************
************************************************************************************************

clear

***************************************************************************
* CREATE FILE OF ZIP CODE LEVEL CHARACTERISTICS
***************************************************************************

import delimited "..\model output\popularity.csv", delimiter("") clear 

gen    segment_number = _n
rename v1 popularity
sort   segment_number

sort segment_number
tempfile temp
save `temp'

import delimited "..\Bay Area Data Files\segment_def.txt", delimiter("") clear 

gen   segment_number = _n
sort  segment_number
merge segment_number using `temp'
drop  _merge

bysort zip_seg: egen tot_zip_stock  = total(segment_stock)
gen    stock_share                  = segment_stock / tot_zip_stock
gen    popularity_zip               = stock_share  * popularity

collapse (sum) popularity_zip (sum) segment_stock, by(zip_seg)

sort zip_seg
tempfile zip
save `zip'

****************************
* CRIME
****************************

use "Data\Crime\Crime.dta", clear

sort  zip_seg
merge zip_seg using `zip'

keep if _merge == 3 | _merge == 2
drop _merge

sort zip_seg
save `zip', replace

****************************
* RESTAURANTS
****************************

use "Data\Restaurants\restaurants.dta", clear

sort  zip_seg
merge zip_seg using `zip'

keep if _merge == 3 | _merge == 2
drop _merge

sort zip_seg
save `zip', replace


****************************
* WEATHER
****************************

use "Data\Weather\Weather.dta", clear

sort zip_seg
merge zip_seg using `zip'

keep if _merge == 3 | _merge == 2
drop _merge

sort zip_seg
save `zip', replace

****************************
* School quality data 
****************************

use "Data\School Quality\API_Quality_AllCA.dta", clear

rename zip_norm zip_seg
keep if year == 2010

keep zip_seg api_total_
rename api_total_ school_quality_api

sort zip_seg
merge zip_seg using `zip'

keep if _merge == 3 | _merge == 2
drop _merge

sort zip_seg
save `zip', replace
	

* Now merge in city data
gen zip_norm = zip_seg
sort zip_norm 
merge zip_norm using  "..\Bay Area Data Files\Zip_To_City.dta" 
keep if _merge == 3
drop zip_norm _merge

**************************************************************
**************************************************************
* Run Some Regressions
**************************************************************
**************************************************************

gen rest_share      = 100 * (eatdrink / segment_stock)

replace cdd = cdd / 1000
replace hdd = hdd / 1000

gen api = school / 100

* MULTIVARIATE FOR PAPER (TABLE 5)
reg  	popularity_zip rest_share api crimeviolent rain cdd hdd, robust
keep if e(sample)

* Also explore within-city (mentioned in text)
reg  	popularity_zip rest_share api crimeviolent rain cdd hdd, absorb(city_norm)	robust


* Univariate (for R2)
reg popularity_zip rest_share, robust
reg popularity_zip api, robust
reg popularity_zip crimeviolent, robust
reg popularity_zip rain, robust
reg popularity_zip cdd, robust
reg popularity_zip hdd, robust

* Univariate within city (for R2)
reghdfe popularity_zip rest_share, absorb(city_norm) vce(robust)	
reghdfe popularity_zip api, absorb(city_norm) vce(robust)
reghdfe popularity_zip crimeviolent, absorb(city_norm) vce(robust)
reghdfe popularity_zip rain, absorb(city_norm) vce(robust)
reghdfe popularity_zip cdd, absorb(city_norm) vce(robust)
reghdfe popularity_zip hdd, absorb(city_norm) vce(robust)
