%% Comparative statics with full model
%    This file allows us to run various comparative static exercises on the
%    fully estimated model

% =========================================================================================================================
% Run "estimate.m"  up to estimation cell, then run this script to get comparative statics  & make Figure 8 of paper
% =========================================================================================================================

close all
clear narrow broad mu_s_array mu_b_array mu_tilde_b_array q_array I_array V_array price_array T_array discount_array

dotsize=30;

%% Define the shocks

eta        = models.full(1).eta;
mu_th      = models.full(1).mu_th;
mu_s       = aggstuff(1).mu_s;
mu_h       = aggstuff(1).mu_h;
ThH        = aggstuff(1).ThH;
Nh         = length(eta);
mu_tilde_b = models.full(1).mu_tilde_b;

% Average match rate entire bay area
avgmatchrate = mu_tilde_b'*((ThH*(mu_s.*models.full(1).mbuy))./(ThH*mu_s))/sum(mu_tilde_b);

%--------------- Select sets of segments to shock
% One segment to record: these are the Daly City & Outer Mission segments
seginds=[16 99];

% Sets 
segindsets = {14:18,98:100};

jointshares=zeros(Nh,Nh);
for ss=1:2
    sel                        = sum(ThH(:,segindsets{ss}),2)>0;       % all types jointly searching with set
    beta_restr                 = beta_tilde(sel)/sum(beta_tilde(sel)); % their rel shares
    ThH_restr                  = ThH(sel,:);                           % restrict to these types
    jointshares(seginds(ss),:) = beta_restr'*ThH_restr;
end

D=length(seginds);

for ss=1:D
    sweights{ss}  = seg_stocks_acs(segindsets{ss})/sum(seg_stocks_acs(segindsets{ss}));
    newhouses{ss} = 1000*sweights{ss}/sum(seg_stocks_acs);
end

%----------- Exercise that adds buyers
newbuyers = 0; % 500/sum(seg_stocks_acs); 
etamultip = 1;

mu_th_array = ones(Nh,1)*mu_th';
eta_array   = (ones(Nh,1)*eta');
mu_h_array  = (ones(Nh,1)*mu_h');
ThH_array   = cell(Nh,1);

% Find buyer who exclusively buys this set
for ss=1:D
    nums = length(segindsets{ss});
    if isempty(find(sum(ThH(:,segindsets{ss}),2)==nums & sum(ThH,2)==nums))
        numbuyer(ss)=1;
        disp(['Specialized buyer not found for set ' num2str(ss)]);
    else
        numbuyer(ss) = find(sum(ThH(:,segindsets{ss}),2)==nums & sum(ThH,2)==nums);
    end
    
    narrow{ss}  = find(sum(ThH(:,segindsets{ss}),2)>0 & sum(ThH,2)<=5);
    middle{ss}  = find(sum(ThH(:,segindsets{ss}),2)>0 & sum(ThH,2)>5 & sum(ThH,2)<21);
    broad{ss}   = find(sum(ThH(:,segindsets{ss}),2)>0 & sum(ThH,2)>20);
    
    eta_array(seginds(ss),segindsets{ss}) = etamultip*eta(segindsets{ss})'; % increase eta
    mu_h_array(seginds(ss),segindsets{ss}) = mu_h(segindsets{ss})' + newhouses{ss}'; % add houses
    mu_th_array(seginds(ss),numbuyer(ss)) = mu_th(numbuyer(ss)) + newbuyers; % add buyers
    ThH_array{seginds(ss)}=ThH;
end

disp('   ')
disp('Properties of selected areas');
disp('   ')

for ss=1:D
    disp('   ')
    disp('-------------------------------------------------------')
    disp(['Experimental Segment Number:  ' num2str(ss)]);
    disp('-------------------------------------------------------')
    disp('   ')
    disp('Segment set');
    disp(segindsets{ss});
    disp('Zip code');
    disp(seg_zips(seginds(ss)));
    disp('Etas');
    disp(eta(segindsets{ss})');
    disp(['Number of houses = ' num2str(sum(seg_stocks_acs(segindsets{ss})))]);
    disp(['Inventory = ' num2str(sum(mu_s(segindsets{ss}))*sum(seg_stocks_acs))]);
    x=models.full(1).mu_tilde_b;
    disp(['Active searchers = ' num2str(sum(x(sum(ThH(:,segindsets{ss}),2)>0))*sum(seg_stocks_acs))]);
    disp(['Interested = ' num2str(sum(mu_th(sum(ThH(:,segindsets{ss}),2)>0))*sum(seg_stocks_acs))]);
    disp('   ')
    disp('----------------');
    disp('Avg popularity - TRUE:');
    disp(aggstuff(1).mu_h(segindsets{ss})'*...
         models.full(1).desire(segindsets{ss})/sum(aggstuff(1).mu_h(segindsets{ss})));
    disp('Avg popularity - HYPOTHETICAL SEGMENTED:');
    disp(aggstuff(1).mu_h(segindsets{ss})'*...
         models.matchbuyers(1).desire(segindsets{ss})/sum(aggstuff(1).mu_h(segindsets{ss})));
end

disp(['Exercise adds ' num2str(newbuyers*sum(seg_stocks_acs)) ' searchers']);
disp(['Exercise adds ' num2str(sum(newhouses{1})*sum(seg_stocks_acs)) ' houses']);

%% Now compute the model D times (Alternative equilibrium after the experiment)

log_q_start = log(models.full(1).q);

deltas=[0.5];

for dd=1:length(deltas)
    mbars{dd} = models.full(1).mbuy .* (models.full(1).q.^(1-deltas(dd)));
end

exitflags=zeros(Nh,length(deltas));
q_array = zeros(Nh,length(deltas),Nh);

for jj = 1:D
             
   disp(jj);
   tic;
    
   for dd = 1:length(deltas)
           
    ThH_calc = ThH_array{seginds(jj)};
    eta_calc = eta_array(seginds(jj),:)';
    mu_h_calc = mu_h_array(seginds(jj),:)';
    mu_th_calc = mu_th_array(seginds(jj),:)';%_array(:,jj);
    
    delta=deltas(dd);
    mbar = mbars{dd};
    
    [log_q,fval,exitflag] = fsolve('fixedpoint_calc',log_q_start,optimset('Display','iter'));     
    
    q_array(seginds(jj),dd,:) = exp(log_q);
    exitflags(seginds(jj),dd) = exitflag;
   
   end
   
   toc; 
end


%% Create other moments of interest

q     = models.full(1).q;
eta   = models.full(1).eta;
I     = aggstuff(1).datamat(:,1);
V     = aggstuff(1).datamat(:,3);  % T=I/V
T     = I./V;
price = aggstuff(1).price;

r            = 0.01/12;
alpha        = eta  ./ (r + 1./T + eta);
kk           = 0.06 ./ T;
price_nofric = price.* (1 + alpha.*kk/r)./(1-alpha); 
discount     = 1 - price./price_nofric;

for dd=1:length(deltas)
    
    delta = deltas(dd);
    mbar  = 1./(T.*q.^delta);
    
    for ss = seginds
        
      qnow     = squeeze(q_array(ss,dd,:));  
      msell    = mbar .* (qnow.^delta);
      mu_s_now = mu_h_array(ss,:)' ./ ( 1 + msell./eta_array(ss,:)');
      
      mu_s_array(ss,dd,:) = mu_s_now;
      I_array(ss,dd,:)    = mu_s_now./mu_h_array(ss,:)';
      mu_b_array(ss,dd,:) = mu_s_now.*qnow;
      V_array(ss,dd,:)    = msell.*mu_s_now./mu_h_array(ss,:)';
      T_array(ss,dd,:)    = 1./msell;
      
      J = ThH_array{ss} * mu_s_now;

      mu_tilde_b_array(ss,dd,:) = J.*mu_th_array(ss,:)'...
                      ./(ThH_array{ss} * (mu_s_now + mu_h_array(ss,:)' ./ qnow)); 
       
      alpha_temp = eta_array(ss,:)' ./ (r + 1./squeeze(T_array(ss,dd,:)) + eta_array(ss,:)');
      kk_temp = .06 ./ squeeze(T_array(ss,dd,:));

      price_array(ss,dd,:) = price_nofric .* (1-alpha_temp) ./ (1 + alpha_temp.*kk_temp/r); 
      discount_array(ss,dd,:) = 1 - squeeze(price_array(ss,dd,:))./price_nofric;

    end
end

%% Changes in outcome variables across segments

disp(' ');disp(' ');disp(' ');
disp('==========================================================');
disp('Changes in Inventory');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

selseg = seginds;

var_name={'T_diff','I_diff','price_diff','jointshare'};
for j=1:2
    i=selseg(j);
    var_values{j} = [log(squeeze(T_array(i,1,:)))-log(T),log(squeeze(I_array(i,1,:)))-log(I),...
                     log(squeeze(price_array(i,1,:)))-log(price),mean(jointshares(segindsets{j},:),1)',...
                     squeeze(I_array(i,1,:))-I];
end

disp('   ')
disp('------------------------------------------')
disp('EXPERIMENT 1 (Daly City Experiment)')
disp('------------------------------------------')
disp('   ')

disp('Average Increase in Inventory from Daly City Experiment in Daly City (94015)');
mean(var_values{1}(14:18,2))
 
disp('Average Increase in Inventory from Daly City Experiment in 94014');
mean(var_values{1}(8:13,2))

disp('Average Increase in Inventory in SF from Experiment in Daly City (94015)');
mean(var_values{1}(78:156,2))

disp('Minimum Increase in Inventory in SF from Experiment in Daly City (94015)');
min(var_values{1}(78:156,2))

disp('Total Increase in Bay Area Inventory from building in Daly City');
sum((squeeze(mu_s_array(16,1,:))-mu_s)*sum(seg_stocks_acs))


disp('   ')
disp('------------------------------------------')
disp('EXPERIMENT 2 (Outer Mission Experiment)')
disp('------------------------------------------')
disp('   ')

disp('Average Increase in Inventory from Outer Mission Experiment in Outer Mission (94112)');
mean(var_values{2}(98:100,2))
 
disp('Average Increase in Inventory in SF from Experiment in Outer Mission (94112)');
mean(var_values{2}(78:156,2))

disp('Minimum Increase in Inventory in SF from Experiment in Outer Mission (94112)');
min(var_values{2}(78:156,2))

disp('Total Increase in Bay Area Inventory from building in Outer Mission');
sum([squeeze(mu_s_array(99,1,:))-mu_s].*sum(seg_stocks_acs))


%% FIGURES FOR PAPERS

disp(' ');disp(' ');disp(' ');
disp('==========================================================');
disp('Figure 8');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

areanow = 'sanfrancisco';
shade={'San Francisco'};
pos = [.02 .11 .47 .81;
       .51 .11 .47 .81];
   
% ================================== 
% Figures for inventory % change
% ================================== 

for v = 2
    
    for j=1:2
        
        figure;
        dotcolor=var_values{j}(:,v);
        
        setup_mapplot3;
                
        i=selseg(j);
        geoshow(zipstruc(zips==seg_zips(i)),'FaceColor',[.8 .8 .8],'EdgeColor',[0 0 0]);
        
        samplot = 1:Nh;%~ismember(1:Nh,segindsets{iseg});
        
        if isequal(areanow,'sanfrancisco')
            caxis(boundaries);
            scatterm(lat_seg_tiny,lon_seg_tiny,dotsize,dotcolor,'filled');
            
        else
            caxis(boundaries);
            scatterm(lat_seg,lon_seg,dotsize,dotcolor,'filled');
        end

        print('-dpdf',[paperdir 'compstat_' num2str(j) var_name{v} '.pdf']);
    end
end

% ================================== 
% Figures for joint searcher share
% ================================== 

for iseg=1:2
        
    figure
    
    dotcolor=var_values{iseg}(:,4);
    setup_mapplot3
    
    hold on;
    
    geoshow(zipstruc(zips==seg_zips(selseg(iseg))),'FaceColor',[.8 .8 .8],'EdgeColor',[0 0 0]);
    
    if isequal(areanow,'sanfrancisco');
        caxis(boundaries);
        scatterm(lat_seg_tiny,lon_seg_tiny,dotsize,dotcolor,'filled');
    else
        caxis(boundaries);
        scatterm(lat_seg,lon_seg,dotsize,dotcolor,'filled');
    end
    
    print('-dpdf',[paperdir 'compstat_joints' num2str(iseg) '.pdf']);
    
end

%% WELFARE CALCULATIONS

disp(' ');disp(' ');disp(' ');
disp('==========================================================');
disp('WELFARE CALCULATIONS');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

% number of happy searchers by type
%  for each type, start from number of buyers
%   divide up into segment in range by inventory share mu_s/ThH(i,:)*mu_s
%     then multiply by (mu_h-mu_s) / mu_b which is same for all types

happy = models.full(1).mu_tilde_b .* (ThH*(mu_s .* (mu_h-mu_s)./models.full(1).mu_b)) ./ (ThH*mu_s);

for ss=1:length(seginds)
    happyX{ss} = squeeze(mu_tilde_b_array(seginds(ss),1,:)) .*  ( ThH_array{seginds(ss)} ...
        * (squeeze(mu_s_array(seginds(ss),1,:)) .* (mu_h_array(seginds(ss),:)'-squeeze(mu_s_array(seginds(ss),1,:)))...
        ./squeeze(mu_b_array(seginds(ss),1,:))) ) ./ (ThH_array{seginds(ss)}*squeeze(mu_s_array(seginds(ss),1,:)));
end

for ex=1:2
    
    disp(' ');disp('================ Comparing owners by type ==============');disp(' ');
    
    disp(['Experiment in Segment ' num2str(ex)]); disp(' ');
    
    disp('Share narrow searchers: ');
    disp([sum(mu_th(narrow{ex})) / (sum(mu_th(narrow{ex})) + sum(mu_th(middle{ex})) + sum(mu_th(broad{ex})))]);
    
    disp('Share middle searchers: ');
    disp([sum(mu_th(middle{ex})) / (sum(mu_th(narrow{ex})) + sum(mu_th(middle{ex})) + sum(mu_th(broad{ex})))]);
    
    disp('Share broad searchers: ');
    disp([sum(mu_th(broad{ex})) / (sum(mu_th(narrow{ex})) + sum(mu_th(middle{ex})) + sum(mu_th(broad{ex})))]);
    
    disp('Initial happy shares: narrow / middle / broad');
    disp([sum(happy(narrow{ex}))./sum(mu_th(narrow{ex}))  sum(happy(middle{ex}))./sum(mu_th(middle{ex})) sum(happy(broad{ex}))./sum(mu_th(broad{ex}))]);
    
    disp('Happy shares after experiment: narrow / middle / broad');
    disp([sum(happyX{ex}(narrow{ex}))./sum(mu_th(narrow{ex}))  sum(happyX{ex}(middle{ex}))./sum(mu_th(middle{ex})) sum(happyX{ex}(broad{ex}))./sum(mu_th(broad{ex}))]);
    
    disp('% change in unhappy number: narrow / middle / broad ');
    disp([sum(happy(narrow{ex})- happyX{ex}(narrow{ex}))./sum(mu_th(narrow{ex})-happy(narrow{ex}))...
          sum(happy(middle{ex})- happyX{ex}(middle{ex}))./sum(mu_th(middle{ex})-happy(middle{ex}))...
          sum(happy(broad{ex})-happyX{ex}(broad{ex}))./sum(mu_th(broad{ex})-happy(broad{ex}))]);
    
end