******************************************************************************************************
* Analyze determinants of search breadth
******************************************************************************************************

cap ssc install binscatter

*********************************************************************************************************************
* Read in data on the share of total inventory which is being looked at by the average person living in the segment
*  - This file is being produced in Matlab
*   
*********************************************************************************************************************

import delimited "..\model output\equilibrium_avg_inventory_scanned.csv", clear
gen  segment_number = _n
gen  search_breadth = 100*v1
drop v1

sort segment_number
tempfile temp
save `temp'

import delimited "..\Bay Area Data Files\segment_def.txt", delimiter("") clear 

gen   segment_number = _n
sort  segment_number
merge segment_number using `temp'
drop  _merge

************************************************************
* Demographics are only known at the zip code level, so we 
* need to collapse the average search breadth to that level
************************************************************

collapse (mean) search_breadth [fweight = segment_stock], by(zip_seg)

************************************************************
* Now merge in zip code demographics
************************************************************

merge zip_seg using "Data\ZipDemo\ZipInc.dta"
sort zip_seg 
cap drop _merge

replace hh_inc_median = hh_inc_median / 1000

sort zip_seg 
merge zip_seg using "Data\ZipDemo\ZipMedAge.dta"
cap drop _merge

sort zip_seg 
merge zip_seg using "Data\ZipDemo\ZipChild.dta"
cap drop _merge


********************************
* Now do the analysis
********************************


* AGE
gen med2 = median_age^2
reg search_breadth median_age med2
local x = 100*round(`e(r2)',0.001)
binscatter search_breadth median_age, n(20) line(qfit) ytitle(Inventory Scanned by Population (%), size(large)) ///
           xtitle(Median Age (Years), size(large)) graphregion(ilcolor(white)) ylabel(,nogrid labsize(large)) ///
		   xlabel(,nogrid labsize(large)) reportreg text(2.2 42 "R-Squared: `x'%", place(e) size(large))
graph export "Figures\Demo_age1.pdf", replace

binscatter search_breadth median_age, n(20) line(qfit) ytitle(Inventory Scanned by Population (%), size(large))  xtitle(Median Age (Years), size(large)) control(hh_inc_median perc_child) graphregion(ilcolor(white)) ylabel(,nogrid labsize(large)) xlabel(,nogrid labsize(large)) reportreg
graph export "Figures\Demo_age2.pdf", replace
 
* Income
gen inc2 = hh_inc_median ^ 2
reg search_breadth inc2 hh_inc_median
local x = 100*round(`e(r2)',0.001)
binscatter search_breadth hh_inc_median, n(20) line(qfit) ytitle(Inventory Scanned by Population (%), size(large)) ///
		   xtitle(Median Income ('000 $), size(large)) graphregion(ilcolor(white)) ylabel(,nogrid labsize(large)) ///
		   xlabel(,nogrid labsize(large)) xlabel(25(25)175) text(2.2 120 "R-Squared: `x'%", place(e) size(large))
graph export "Figures\Demo_inc1.pdf", replace

binscatter search_breadth hh_inc_median, n(20) line(qfit) ytitle(Inventory Scanned by Population (%), size(large))  xtitle(Median Income ('000 $), size(large)) control(median_age perc_child) graphregion(ilcolor(white)) ylabel(,nogrid labsize(large)) xlabel(,nogrid labsize(large))
graph export "Figures\Demo_inc2.pdf", replace

* Children
gen child2 = perc_child ^ 2
reg search_breadth child2 perc_child
local x = 100*round(`e(r2)',0.001)
binscatter search_breadth perc_child, n(20) line(qfit) ytitle(Inventory Scanned by Population (%), size(large)) ///
		   xtitle(Share with Children (%), size(large))  graphregion(ilcolor(white)) ylabel(,nogrid labsize(large)) ///
		   xlabel(,nogrid labsize(large)) text(2.2 15 "R-Squared: `x'%", place(e) size(large))
graph export "Figures\Demo_child1.pdf", replace

binscatter search_breadth perc_child, n(20) line(qfit) ytitle(Inventory Scanned by Population (%), size(large))  xtitle(Share with Children (%), size(large)) control(median_age hh_inc_median) graphregion(ilcolor(white)) ylabel(,nogrid labsize(large)) xlabel(,nogrid labsize(large))
graph export "Figures\Demo_child2.pdf", replace
