************************************************************************************************
************************************************************************************************
*
* COMPARE THE ZIP CODE TO ZIP CODE MOVEMENTS THAT ARE PREDICTED BY THE MODEL TO THE MOVING
* DATA THAT WE OBTAINED FROM AXCIOM
*
************************************************************************************************
************************************************************************************************

import delimited "..\Bay Area Data Files\segment_def.txt", delimiter("") clear 

gen   segment_number = _n
sort  segment_number
keep  segment_number zip_seg

tempfile temp
save `temp'

import delimited "..\model output\segment_to_segment_flow.csv", clear

gen segment_from = _n
reshape long v, i(segment_from) j(segment_to)
rename v share_moves_model

gen segment_number = segment_from

sort segment_number
merge segment_number using `temp'

gen  zip_from = zip_seg
keep segment_from segment_to share_moves_model zip_from

gen segment_number = segment_to

sort  segment_number
merge segment_number using `temp'

gen zip_to = zip_seg
keep segment_from segment_to share_moves_model zip_from zip_to

collapse (sum) share_moves_model, by(zip_from zip_to)

sort  zip_from zip_to
merge zip_from zip_to using "..\Bay Area Data Files\Zip_Zip_Moves_Real.dta"

keep if _merge == 1 | _merge == 3

egen total_moves      = total(n)
gen  share_moves_data = n / total_moves

replace share_moves_data = 0 if _merge == 1	


**********************************
* Compare bilateral moving shares
**********************************

corr share_moves_model share_moves_data
	
preserve
	drop if zip_from != zip_to
	egen tot_mod              = total(share_moves_model)
	egen tot_data             = total(share_moves_data) 
	replace share_moves_data  = share_moves_data / tot_data
	replace share_moves_model = share_moves_model / tot_mod
	corr share_moves_model share_moves_data
restore


twoway (scatter share_moves_data share_moves_model, msize(small)), ytitle(Move Share in Data) xtitle(Move Share in Model) scheme(s1mono)
graph export "Figures\Moves.pdf", replace
