%% Comparative statics with a model calibrated to entire Bay Area
%  This file allos us to run comparative statics exercises on a model
%  calibrated to just one "Bay Area" segment

% Produces numbers in Section 6 
% To prepare, run "estimate.m" up to estimation cell

clear mu_s_array mu_b_array mu_tilde_b_array q_array I_array V_array price_array T_array discount_array

bayarea = 1;
deltas  = [.5];

Nh=1;
ThH   = ones(1,length(seg_stocks_acs));
mu_th = models.matchbuyers(5).mu_th;
eta   = models.matchbuyers(5).eta;
mu_h  = aggstuff(5).mu_h;
mu_s  = aggstuff(5).mu_s;

log_q_start = log(models.matchbuyers(5).q);
mbars{1}    = models.matchbuyers(5).mbuy .* (models.matchbuyers(5).q.^(1-deltas(dd)));

q     = models.matchbuyers(5).q;
I     = aggstuff(5).datamat(:,1);
V     = aggstuff(5).datamat(:,3);  
T     = I./V;
price = aggstuff(5).price;

D          = 1;
seginds    = 1;
segindsets = {1};

% Exeriment that adds 1000 new houses
newhouses{1}=1000/sum(seg_stocks_acs);

% Exercise that adds buyers
newbuyers = 0;%500/sum(seg_stocks_acs);%0002; % number of new agents
etamultip = 1;

mu_th_array = ones(Nh,1)*mu_th';
eta_array   = (ones(Nh,1)*eta');
mu_h_array  = (ones(Nh,1)*mu_h');%+ 10*diag(mu_h/100);
ThH_array   = cell(Nh,1);

% Find buyer who exclusively buys this city
for ss=1:D
    nums = length(segindsets{ss});
    if isempty(find(sum(ThH(:,segindsets{ss}),2)==nums & sum(ThH,2)==nums))
        numbuyer(ss)=1;
        disp(['specialized buyer not found for set ' num2str(ss)]);
    else
        numbuyer(ss) = find(sum(ThH(:,segindsets{ss}),2)==nums & sum(ThH,2)==nums);
    end
    
    %  % define narrow and broad searchers: index sets for each experiment
    %  %    narrow = search in one of segments in set, and below cutoff
    %  narrow{ss} = find(sum(ThH(:,segindsets{ss}),2)>0 & sum(ThH,2)<=nums);
    %  broad{ss} = find(sum(ThH(:,segindsets{ss}),2)>0 & sum(ThH,2)>20);
    %
    eta_array(seginds(ss),segindsets{ss})  = etamultip*eta(segindsets{ss})'; % increase eta
    mu_h_array(seginds(ss),segindsets{ss}) = mu_h(segindsets{ss})' + newhouses{ss}'; % add houses
    mu_th_array(seginds(ss),numbuyer(ss))  = mu_th(numbuyer(ss)) + newbuyers; % add buyers
    ThH_array{seginds(ss)}                 = ThH;
end;


disp('==================== Properties of selected areas==');
for ss=1:D;
    disp('Segment set');
    disp(segindsets{ss});
    disp('Etas');
    disp(eta(segindsets{ss})');
    if bayarea
        disp(['Number of houses = ' num2str(sum(seg_stocks_acs))]);
    else
        citystocks = aggcity * seg_stocks_acs;
        disp(['Number of houses = ' num2str(sum(citystocks(segindsets{ss})))]);
    end
    disp(['Inventory = ' num2str(sum(mu_s(segindsets{ss}))*sum(seg_stocks_acs))]);
    x=mu_th - mu_h;
    disp(['Active searchers = ' num2str(sum(x(sum(ThH(:,segindsets{ss}),2)>0))*sum(seg_stocks_acs))]);
    disp(['Interested = ' num2str(sum(mu_th(sum(ThH(:,segindsets{ss}),2)>0))*sum(seg_stocks_acs))]);
    disp('----------------');
end

disp(['Exercise adds ' num2str(newbuyers*sum(seg_stocks_acs)) ' searchers']);
disp(['Exercise adds ' num2str(sum(newhouses{1})*sum(seg_stocks_acs)) ' houses']);

%% Now compute the model D times

exitflags=zeros(Nh,length(deltas));
q_array = zeros(Nh,length(deltas),Nh);

for jj = 1:D;
    
    disp(jj);
    tic;
    
    for dd = 1:length(deltas);
        
        ThH_calc = ThH_array{seginds(jj)};
        eta_calc = eta_array(seginds(jj),:)';
        mu_h_calc = mu_h_array(seginds(jj),:)';
        mu_th_calc = mu_th_array(seginds(jj),:)';%_array(:,jj);
        
        delta=deltas(dd);
        mbar = mbars{dd};
        
        [log_q,fval,exitflag] = fsolve('fixedpoint_calc',log_q_start,optimset('Display','iter'));
        
        q_array(seginds(jj),dd,:)=exp(log_q);
        exitflags(seginds(jj),dd) = exitflag;
        
    end
    
    toc;
end

%------------------ Create other moments of interest
r            = 0.01/12;
alpha        = eta ./ (r + 1./T + eta);
kk           = 0.06 ./ T;
price_nofric = price.* (1 + alpha.*kk/r)./(1-alpha);
discount     = 1 - price./price_nofric;

for dd=1:length(deltas)
    delta = deltas(dd);
    mbar = 1./(T.*q.^delta);
    
    for ss=seginds%1:Nh;
        
        qnow     = squeeze(q_array(ss,dd,:));
        msell    = mbar .* (qnow.^delta);
        mu_s_now = mu_h_array(ss,:)' ./ ( 1 + msell./eta_array(ss,:)');
        
        mu_s_array(ss,dd,:) = mu_s_now;
        I_array(ss,dd,:)    = mu_s_now./mu_h_array(ss,:)';
        mu_b_array(ss,dd,:) = mu_s_now.*qnow;
        V_array(ss,dd,:)    = msell.*mu_s_now./mu_h_array(ss,:)';
        T_array(ss,dd,:)    = 1./msell;
        
        J = ThH_array{ss} * mu_s_now;
        
        mu_tilde_b_array(ss,dd,:) = J.*mu_th_array(ss,:)'...
            ./(ThH_array{ss} * (mu_s_now + mu_h_array(ss,:)' ./ qnow));
        
        alpha_temp = eta_array(ss,:)' ./ (r + 1./squeeze(T_array(ss,dd,:)) + eta_array(ss,:)');
        kk_temp    = 0.06 ./ squeeze(T_array(ss,dd,:));
        
        price_array(ss,dd,:) = price_nofric .* (1-alpha_temp) ./ (1 + alpha_temp.*kk_temp/r);
        discount_array(ss,dd,:) = 1 - squeeze(price_array(ss,dd,:))./price_nofric;
        
    end
end

%% OUTPUT FOR PAPER

selseg = seginds;

var_name={'T_diff','I_diff','price_diff','jointshare'};
for j=1:length(seginds)
    i=selseg(j);
    var_values{j} = [log(squeeze(T_array(i,1,:)))-log(T),log(squeeze(I_array(i,1,:)))-log(I),...
                     log(squeeze(price_array(i,1,:)))-log(price),zeros(Nh,1),...
                     squeeze(I_array(i,1,:))-I];
end

% BAY AREA AGGREGATE STATS
disp('Aggregate inventory before, after');
disp([mu_s mu_s_now]*sum(seg_stocks_acs))

disp('Difference');
disp([mu_s_now-mu_s]*sum(seg_stocks_acs))   % Note: If inventory increases more than housing stock, this is a welfare reduction (see Section 4)