%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Requires running makezipdata.m and make_pop first!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Initialize the data

clear all;
close all;
global T V delta eta mu_th_cond mu_th_condM inds_cl qlast alpha formula
global eta_c mu_h_c fbar mbar buyers_fixed
global buyerT beta_tilde_calc ThH_calc eta_calc mu_h_calc mu_th_calc mu_s J_calc volshare

% load data prepared by makezipdata.m
load inistuff;

% Find current directory
dirroot = pwd;

datadir  = [dirroot '\Bay Area Data Files\'];
paperdir = [dirroot '\figures\'];

printflag = 1;

tsmeans      = tsmeans_array{2}; 
tsmeans_zip  = tsmeans_array{4}; 
tsmeans_city = tsmeans_array{6}; 

%% Clean aggcity matrix that aggregates across cities

% Handle Tiburon: two citynames, one zipcode, use version dep one
aggcity   = aggcity([1:7 9:97],:);
citynames = citynames([1:7 9:97]);


% Address the fact that aggcity contains subcities; Disaggregate everything to the smallest city!
trouble = find(sum(aggcity)>1);                       % Seg indices where > 1 city
while ~isempty(trouble)
    inds = find(aggcity(:,trouble(1)));               % Take 1st such segment
    [keep,keepi] = min(sum(aggcity(inds,:),2));       % Find smallest city
    aggcity(inds,trouble(1))= zeros(size(inds,1),1);  % Exclude from all
    aggcity(inds(keepi),trouble(1))=1;                % Include only in smallest
    seg_cities(trouble(1))=inds(keepi);
    seg_citiesN(trouble(1))=citynames(inds(keepi));
    trouble=find(sum(aggcity)>1);
end

%% County information

% Note: San Benito is only 3 segments in Hollister; count as Santa Clara
county_names_orig = {'Alameda','ContraCosta','Marin','SanBenito','SanFrancisco','SanMateo','SantaClara'};
county_numbers = [1  2  1  2  6  2  6 ...
                  3  1  2  2  6  6 ...
                  7  1  2  6  2  3  6 ...
                  7  6  2  2  1  6 ...
                  2  2  6  1  3  6 ...
                  1  7  3  6  1  2  6 ...
                  4  2  3  2  3  1  7 ...
                  7  7  2  6  3  6 ...
                  7  7  2  7  7  3 ...
                  1  3  1  2  2  2  6 7 ...
                  6  1  2  2  2  1 ...
                  6  6  2  2  3  6 ...
                  6  5  7  1  1  7 ...
                  6  2  3  2  7  7 ...
                  3  6  7  1  2  6];

aggcounty_c = zeros(length(county_names_orig),size(aggcity,1));
for cc=1:length(county_names_orig);
    aggcounty_c(cc,:) = (county_numbers==cc);
end

% Aggregate santa clara and san benito
aggcounty_c = [aggcounty_c([1:3 5 6],:); aggcounty_c(4,:)+aggcounty_c(7,:)];
aggcounty = aggcounty_c*aggcity;
seg_counties = aggcounty' * [1:6]';
county_names = {'Alameda','ContraCosta','Marin','SanFrancisco','SanMateo','SantaClara'};

%% Formulate everything in terms of model parameters & notation

% File contains matrix ThH (NthxNh) and betatilde constructed by the code make_pop.m
load ThH_matrix

tsmeans(tsmeans(:,6)== 0,6)=mean(tsmeans(:,6));

[Nth,Nh]  = size(ThH);

% Trade statistics by market
mu_h  = seg_stocks_acs/sum(seg_stocks_acs); % Total housing stock =1
T     = tsmeans(:,6);
V     = tsmeans(:,1);
I_raw = tsmeans(:,4);
hot   = tsmeans(:,5);
price = tsmeans(:,2);
mu_s  = T.*V.*mu_h;       
I     = T.*V;
eta   = 1./(1./V - T);

% Also by zipcode
T_zip   = tsmeans_zip(:,6);
V_zip   = tsmeans_zip(:,1);
I_zip   = tsmeans_zip(:,4);
hot_zip = tsmeans_zip(:,5);

% Type specific inventory: Does depend on ThH
J           = ThH * mu_s;                      % (Nth x 1) Share of inventory scanned by types
mu_tilde_h  = ThH * mu_h;                      % (Nth x 1) Share of stock scanned by types
price_tilde = (ThH*(mu_h.*price)./(ThH*mu_h));

% Benchmark: Fully segmented case
ThH_seg        = eye(Nh);
beta_tilde_seg = mu_h.*(ThH'*(beta_tilde./mu_tilde_h)); % share of buyers in each segment (out of total buyers)
mu_tilde_s_seg = ThH_seg * mu_s;

%% Additional definitions needed below

for zz=1:length(zip2)
    zipnow = str2num(zip2(zz).ZCTA5CE10);
    %if sum(zipcode==zipnow);
    zip2(zz).T_zip   = T_zip(zipcode==zipnow);
    zip2(zz).hot_zip = hot_zip(zipcode==zipnow);
    zip2(zz).V_zip   = V_zip(zipcode==zipnow);
    zip2(zz).density = (mu_h(zipcode==zipnow)/zip2(zz).ALAND10);
    density(zz)      = (mu_h(zipcode==zipnow)/zip2(zz).ALAND10);

    dens(seg_zips==zipnow)=  (mu_h(zipcode==zipnow)/zip2(zz).ALAND10);
    
end

% Prepare inputs for maps

zipstruc=zip2;
nn=fieldnames(zip2);
for zz=1:length(zip2)
    zipnow = str2num(zip2(zz).ZCTA5CE10);
    ii=find(zips==zipnow);
    for ff=1:length(nn)
        zipstruc(ii).(nn{ff}) = zip2(zz).(nn{ff});
    end
end

% Topcoded data - better for plots
tsmeansT                                = tsmeans;
tsmeans_zipT                            = tsmeans_zip;
tsmeansT(tsmeans(:,1)>.12/12,1)         = .12/12;
tsmeansT(tsmeans(:,3)>8,3)              = 8;
tsmeans_zipT(tsmeans_zip(:,1)>.12/12,1) = .12/12;
tsmeans_zipT(tsmeans_zip(:,3)>8,3)      = 8;

TT     = tsmeansT(:,3);
VT     = tsmeansT(:,1);
T_zipT = tsmeans_zipT(:,3);
V_zipT = tsmeans_zipT(:,1);
IT     = VT.*TT;

% Price groups
pricecuts = [0 2.5e5 5e5 7.5e5 1e6 3e6];
pricemids = (pricecuts(2:end)+pricecuts(1:end-1))/2;
aggprice  = zeros(length(pricecuts)-1,Nh);
for pp=1:length(pricecuts)-1
    aggprice(pp,:)=price>pricecuts(pp)&price<=pricecuts(pp+1);
end

%% Define cuts

% Aggmatrix gives level of aggregation
bigcities = find(aggcity*mu_h>.04);

% Area price intersection sets
prgroups     = size(aggprice,1);

aggcountyprice = [];
count=1;

for cc=1:size(aggcounty,1)
    aggcountyprice=[aggcountyprice;(ones(prgroups,1)*aggcounty(cc,:)).*aggprice];
    
    for pp=1:length(pricemids)
        countypricenames{count} = [county_names{cc} ',  ' num2str(pricemids(pp)/1000,'%4.0f')];
        count=count+1;
    end
    
end

% Zip code names
for zz=1:length(zipcode)
    zipnames{zz}=num2str(zipcode(zz));
end

% How to display city names and numbers
%for k=1:Nh;disp([num2str(cli_share.area(k)) '   ' seg_citiesN{k}]);end

%% Build locally aggregated areas

% For each segment, find area that is connected by sufficiently many searchers
q_tildeK = beta_tilde ./ mu_tilde_h;

agglocal=zeros(Nh,Nh);
agglocalcut=zeros(Nh,Nh);
localcutnames=cell(Nh,1);
cutoff=.3;

for ss=1:Nh
    
    % Segment that are ever searched jointly with segment ss
    agglocal(ss,:) = sum(ThH(ThH(:,ss)>0,:))>0;
    
    % All types who search ss
    ssearch = ThH(ThH(:,ss)>0,:);
    
    % Vector of demands contributed by types in ss
    q_tilde_ss    = q_tildeK(ThH(:,ss)>0);
    demshares{ss} = q_tilde_ss/sum(q_tilde_ss);
    
    % Share of demand searching jointly other segments and ss
    connshares{ss} = demshares{ss}'*ssearch;
    
    % Segments connected to ss by searchers with demand share > cutoff in
    % ss (note that there is no condition on a high demand share elsewhere)
    agglocalcut(ss,:) = connshares{ss}>cutoff;
    localcutnames{ss} = [seg_citiesN{ss} '   ' num2str(price(ss)/1000,'%4.0f')];
    
end



%% Clientele statistics by market: Definitions

%  Clientele weight (How important is a certain clientele in a market)
%  cl_weight = Nth x Nh matrix s.t. nonzero i j entry gives
%              share of searcher type i among all searchers who search in market j

mu_scan_ThH = (repmat(beta_tilde,1,Nh).*ThH);                  % Sum over searcher shares by market
cl_weight   = mu_scan_ThH ./ repmat(sum(mu_scan_ThH,1),Nth,1); % Make weights

cli_raw     = ThH'*beta_tilde;          % Share of buyers interested in h (i.e. fraction that scan this market)
bs_raw      = ThH'*beta_tilde./mu_h;    % share of buyers interested in h rel to houses in h

bs_weightednum = (beta_tilde' * (ThH./repmat(sum(ThH,2),1,Nh)))'./mu_h;

% This is same as  ThH'*(beta_tilde./mu_tilde_h)
bs_weightedh   = (beta_tilde' * (ThH.*repmat(mu_h',Nth,1) ./ repmat(mu_tilde_h,1,Nh)))'./mu_h;

% Same as  ThH'*(beta_tilde./J) .* (mu_s./mu_h)
bs_weightedinv = (beta_tilde' * (ThH.*repmat(mu_s',Nth,1) ./ repmat(J,1,Nh)))'./mu_h;

demand = ThH'*(beta_tilde./J) .* mu_s;

bs_weightedhT                   = bs_weightedh;
bs_weightedhT(bs_weightedh>2.5) = 2.5;

bs_weightedinvT = bs_weightedinv;
bs_weightedinvT(bs_weightedinv>4)=4;

% Variables to examine:
propnames   = {'inventory','housing stock'};
marketprops = [J,mu_tilde_h];
marketcomps = [mu_s,mu_h];

% Quantiles to be computed for each
quants = [.25 .5 .75];

% Compute means and set up quantile arrays
for mm= 1 : size(marketprops,2)
    mean_array{mm}      = cl_weight'*marketprops(:,mm);
    quantiles_array{mm} = zeros(Nh,length(quants));
end

% Compute quantiles
for hh=1:Nh
    for mm=1:size(marketprops,2)
        quantiles_array{mm}(hh,:) = quantile_w(marketprops(:,mm),cl_weight(:,hh),quants)';
    end
end

% Carry these over at segment level to compare to other variables
medianinv = quantiles_array{1}(:,2)/sum(marketcomps(:,1));
IQinv     = (quantiles_array{1}(:,3) - quantiles_array{1}(:,1))/sum(marketcomps(:,1));


%% ====================================================================
%  FIGURE B.2: Price variation within zip codes across segments
%  ====================================================================

dotsize=20;
priceT              = price;
priceT(price>1.5e6) = 1.5e6;   
priceT              = priceT/1000;

% SAN FRANCISCO
varnames={'priceT'};
areas={'sanfrancisco'};
shade={'San Francisco'};
map_by_area;
colorbar;
title('  ');
print('-dpdf',[paperdir 'price_sf.pdf']);

varnames={'priceT'};
areas={'bayarea'};
shade={'San Francisco'};
map_by_area;
title('  ');
print('-dpdf',  [paperdir 'price_bayarea.pdf']);

%% Aggregate to different levels

dotscale = 30;
logprice = log(price);

varnames={'I','bs_weightedh','V','price'};

% Weights for aggregation - not normalized!
weights={'mu_h','mu_h','mu_h','mu_h'};

% Agg unit names and formulas for aggregation matrices, first must be segment!
aggbayarea  = ones(1,Nh);
unitsmain   = {'segment','zip','city','county','bayarea','countyprice','price','local','localcut'};
aggmatrices = {'eye(Nh)','aggzip', 'aggcity','aggcounty','aggbayarea','aggcountyprice','aggprice','agglocal','agglocalcut'};

alpha=0.5;

for agg = 1:length(unitsmain)
    
    aggnow = eval(aggmatrices{agg});
    
    N_agg = size(aggnow,1);
    aggstuff(agg).N_agg = N_agg;
    
    % Form weighted aggregate for each variable  
    for i=1:length(varnames)
        weightnow                   = eval(weights{i});
        aggstuff(agg).(varnames{i}) = (aggnow*(weightnow.*eval(varnames{i})))./(aggnow*weightnow);
    end
    
    % Common clientele for unit
    aggstuff(agg).cli = (sum(aggnow,2)>0).*((ThH*aggnow'==(ones(Nth,1)*sum(aggnow,2)'))'*beta_tilde);
    
    % Common demand for unit
    aggstuff(agg).demand = (aggnow*mu_s).*((ThH*aggnow'==(ones(Nth,1)*sum(aggnow,2)'))'*(beta_tilde./J));
    buyersperJ = (sum(aggnow,2)>0).*((ThH*aggnow'==(ones(Nth,1)*sum(aggnow,2)'))'*(beta_tilde./J));
    aggstuff(agg).slope = buyersperJ;
    
    % Total inventory in unit searched by each type (Nth x #units)
    invunitnow = ThH * (aggnow' .* (mu_s*ones(1,size(aggnow,1))));
    
    % Is the type i (in rows) an integrator of unit j (in cols)
    integrator = (invunitnow > alpha*ones(Nth,1)*mu_s'*aggnow');
    
    % Aggregated (to unit) demand by searchers who scan 50% or more of unit
    aggstuff(agg).demand50 = (sum(aggnow,2)>0).*((integrator.*invunitnow)'*(beta_tilde./J));
    
    % Share of unit clientele in segment clientele
    if agg>1
        cli_share.(unitsmain{agg})    = (aggnow'*aggstuff(agg).cli) ./ (ThH'*beta_tilde);
        int_demand.(unitsmain{agg})   = mu_s.*(aggnow'*buyersperJ);
        int_demand50.(unitsmain{agg}) = mu_s.*(ThH' .* (aggnow'*integrator')*(beta_tilde./J));
    end
    
    aggstuff(agg).logprice = log(aggstuff(agg).price);
    
end

%% Form data set with aggregated variables & new weights from stock

varnames={'I','bs_weightedh','V','log(price)'};

for agg = 1:length(unitsmain)
    
    aggnow = eval(aggmatrices{agg});
    N_agg  = size(aggnow,1);
    
    weightnow               = mu_h;
    aggweight               = aggnow*weightnow;
    aggstuff(agg).aggweight = aggweight;
    datamat                 = zeros(N_agg,length(varnames));
    
    for i=1:length(varnames)
        datamat(:,i) = (aggnow*(weightnow.*eval(varnames{i})))./aggweight;
    end
    
    aggstuff(agg).datamat = datamat;
    
    % Moments of variables aggregated to unit
    aggstuff(agg).means = aggweight'*datamat;
    
    covs                   = datamat'*diag(aggweight)*datamat - aggstuff(agg).means'*aggstuff(agg).means;
    aggstuff(agg).aggvars  = diag(covs);
    aggstuff(agg).aggcorrs = covs ./ sqrt(diag(covs)*diag(covs)');
    
    if agg > 1
        
        varsu  = zeros(N_agg,length(varnames));
        corrsu = zeros(N_agg,length(varnames),length(varnames));
        
        for uu = 1:size(aggnow,1)
            selu          = logical(aggnow(uu,:));
            datau         = aggstuff(1).datamat(selu,:);
            weightu       = mu_h(selu)/(aggnow(uu,:)*mu_h);
            meanu         = weightu'*datau;
            covsu         = datau'*diag(weightu)*datau - meanu'*meanu;
            varsu(uu,:)   = diag(covsu);
            corrsu(uu,:,:)= covsu ./ sqrt(diag(covsu)*diag(covsu)');
        end
        
        aggstuff(agg).varsu = varsu;
        aggstuff(agg).corrsu = corrsu;
        
        minsegnum=1;
        haswithinvar = sum(aggnow,2)>minsegnum;
        
        aggstuff(agg).condvars = mean(varsu(haswithinvar,:),1)';
        aggstuff(agg).condcorrs = squeeze(mean(corrsu(haswithinvar,:,:),1));
        
    end
        
    ThHunit = (ThH * aggnow' > 0);
    aggstuff(agg).ThH = ThHunit;
    
    aggstuff(agg).mu_s = aggnow*mu_s;
    aggstuff(agg).mu_h = aggnow*mu_h;
        
    % Number of units searched by type
    numunits = sum(ThHunit,2);
    
    % Record number of units searched for each guy and unit
    mat_numunits = diag(numunits)*ThHunit;
    
    % Share of inventory of units searched by agent
    invshares = (ThH * mu_s) ./ (ThHunit*aggnow*mu_s);
    
    % For each agent, unit, share of all unit inv i.e. inv that he "should" invest in replicates the numbers
    mat_invshares = diag(ThH * mu_s) * ( ThHunit ./ (ThHunit*aggnow*mu_s *ones(1,size(aggnow,1)) ) );
    
    aggstuff(agg).numunits      = numunits;
    aggstuff(agg).mat_numunits  = mat_numunits;
    aggstuff(agg).invshares     = invshares;
    aggstuff(agg).mat_invshares = mat_invshares;
    
    % Summarize from the unit perspective
    interest = beta_tilde' * ThHunit;
    aggstuff(agg).exactly_one = (beta_tilde'*(mat_numunits==1 & mat_invshares==1)) ./ interest;
    aggstuff(agg).below_one   = (beta_tilde'*(mat_numunits==1 & mat_invshares<1))  ./ interest;
    aggstuff(agg).multiple    = (beta_tilde'*(mat_numunits>1 & mat_invshares==1))  ./ interest;
    aggstuff(agg).connect     = (beta_tilde'*(mat_numunits>1 & mat_invshares<1))   ./ interest;
    
end

aggstuff(2).names=citynames(bigcities);
 
%% Segment-Level Market Activity Facts

disp(' ');disp(' ');disp(' ');
disp('========================================================================================');
disp('OUTPUT FOR TABLE 2 OF THE PAPER (Summary statistics of market and search activity)');
disp('========================================================================================');
disp(' ');disp(' ');disp(' ');

disp('----------------------------------------------------')
disp('Inventory Share: aggregate, min, quantiles, max');
100*sum(aggstuff(1).I .* aggstuff(1).mu_h)
100*min(aggstuff(1).I)
100*quantile(aggstuff(1).I,[.25 .5 .75])
100*max(aggstuff(1).I)

disp('----------------------------------------------------')
disp('Turnover rate: aggregate, min, quantiles, max');
100*sum(aggstuff(1).V .* aggstuff(1).mu_h)
100*min(aggstuff(1).V)
100*quantile(aggstuff(1).V,[.25 .5 .75])
100*max(aggstuff(1).V)

% Sigma (Demand)
disp('----------------------------------------------------')
disp('Sigma: aggregate, min, quantiles, max');
average_sigma = sum(aggstuff(1).bs_weightedh.* aggstuff(1).mu_h);
sum(aggstuff(1).bs_weightedh .* aggstuff(1).mu_h) / average_sigma
min(aggstuff(1).bs_weightedh) / average_sigma
quantile(aggstuff(1).bs_weightedh,[.25 .5 .75]) ./ average_sigma
max(aggstuff(1).bs_weightedh) / average_sigma

disp('-------')
disp('Zip Code of Max Search Segment');
disp(sum([aggstuff(1).bs_weightedh == max(aggstuff(1).bs_weightedh)].*seg_zips))

disp('-------')
disp('Zip Code of Min Search Segment');
disp(sum([aggstuff(1).bs_weightedh == min(aggstuff(1).bs_weightedh)].*seg_zips))

% House Prices
disp('-------')
disp('House Prices: aggregate, min, quantiles, max');
sum(exp(aggstuff(1).logprice) .* aggstuff(1).mu_h)/1000
min(exp(aggstuff(1).logprice))/1000
quantile(exp(aggstuff(1).logprice),[.25 .5 .75])/1000
max(exp(aggstuff(1).logprice))/1000

% Housing Stock -- See "Other Stata Files"

%% Facts by level of aggregation
%  Produces output for Table 3 of the paper ("Cross sectional variation in market and search activity")
%  NB: localcut is the "connected area" measure.

disp(' ');disp(' ');disp(' ');
disp('==========================================================');disp('==========================================================');
disp('OUTPUT FOR TABLE 3 OF THE PAPER');
disp('==========================================================');disp('==========================================================');
disp(' ');disp(' ');disp(' ');

for agg=1:3
    
    disp('==========================================================');
    disp(['UNIT OF OBSERVATION: ',unitsmain{agg}])
    disp('==========================================================');disp(' ');

    disp('  '); disp(['Volatility']);
    disp('      I       search      V      logprice');
    disp(round(100*(sqrt(aggstuff(agg).aggvars')),2))
    disp(round(sqrt(aggstuff(agg).aggvars'),2))
    
    disp('  '); disp(['Share of segment variance'])
    disp('      I       search      V      logprice');
    disp(aggstuff(agg).aggvars'./aggstuff(1).aggvars');
    
    disp('  '); disp(['Across-Correlations [Left Panels of Table 3]  --  Level:  ' unitsmain{agg}]);
    disp('      I       search      V      logprice');
    disp(round(aggstuff(agg).aggcorrs,2))
    
    if agg > 1
        
        disp('  '); disp(['Volatility']);
        disp('      I       search      V      logprice');
        disp(round(100*(sqrt(aggstuff(agg).condvars')),2))
        disp(round(sqrt(aggstuff(agg).condvars'),2))
        
        disp('  '); disp(['Within-Correlations [Right Panels of Table 3]  --  Level:  ' unitsmain{agg}]);
        disp('      I       search      V      logprice');
        disp(round(aggstuff(agg).condcorrs,2));
        
    end
end


disp('==========================================================');
disp('Beveridge curve slopes');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

for agg=2:4
    bevcorr{agg} = squeeze(aggstuff(agg).corrsu(:,1,2));
end

% How many cities is it upward sloping?
% [bevcorr{3} sum(aggcity')']  % Shows that correlations are zero when there is only one segment; and perfect (==1) if there are two segments

disp('How many cities do we have with at least two segments?');
sum(sum(aggcity')' > 1)
disp('In how many of those is Beveridge curve upwards sloping?');
sum((sum(aggcity')' > 1).*(bevcorr{3} > 0))
disp('Share of housing stock in cities with (i) at least 2 segments, and (ii) positive Beveridge curve');
sum((sum(aggcity')' > 1).*(bevcorr{3} > 0).*aggstuff(3).mu_h)./sum(sum(aggstuff(3).mu_h))

%--------------------------------
% Other stats cited: for top 25
%--------------------------------

%sortrows([aggstuff(3).mu_h bevcorr{3}],1)  % Show beveridge curve for cities by size
%mean(bevcorr{3}(sum(aggcity,2)>7 & bevcorr{3}>0))

disp('Statistics within the 25 largest: mean, quantiles');
x1 = sortrows([aggstuff(3).mu_h bevcorr{3}],1);
x2 = x1(end-24:end,2);
mean(x2)
quantile(x2,[.25 .5 .75])
sum(x2>0)

%% SEARCH PATTERNS BY AGG LEVEL
%---------------------------------------------------------------------------------
%  This produces output for Table B.1 of the paper "Variation in Scanned Inventory"
%------------------------------------------------------------------------------

disp('==========================================================');
disp('Table B.1');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

%--------------------------------------------
% Columns 2 and 3 (Total Inventory Scanned)
%--------------------------------------------

% Usese medianinv and IQinv from above

disp('Col 1, Table B.1')
round(100*mean(medianinv),2)
round(100*quantile(medianinv,[.25 .5 .75]),2)

disp('Col 2, Table B.1')
round(100*mean(IQinv),2)
round(100*quantile(IQinv,[.25 .5 .75]),2)

disp('Correlation bw Col 1 and Col 2, Table B.1')
corr(medianinv, IQinv)

%--------------------------------------------
% Remaining Columns
%--------------------------------------------

for agg=2:3
    disp(['======= search patterns by ' unitsmain{agg}]);
    disp('share searching exactly one unit');
    x = aggstuff(agg).exactly_one;
    disp('     mean        min       max      q25      q50      q75       std')
    disp(round(100*[mean(x) min(x) max(x) quantile(x,[.25 .5 .75]) std(x)],1));
    disp('multiple exact units (many)');
    disp('     mean        min       max      q25      q50      q75       std')
    x=aggstuff(agg).multiple;
    disp(round(100*[mean(x) min(x) max(x) quantile(x,[.25 .5 .75]) std(x)],1));
    disp('less than one unit searched (subset)');
    disp('     mean        min       max      q25      q50      q75       std')
    x=aggstuff(agg).below_one;
    disp(round(100*[mean(x) min(x) max(x) quantile(x,[.25 .5 .75]) std(x)],1));
    disp('connecting units (other)');    
    disp('     mean        min       max      q25      q50      q75       std')
    x=aggstuff(agg).connect;
    disp(round(100*[mean(x) min(x) max(x) quantile(x,[.25 .5 .75]) std(x)],1));
end



%% Beveridge Curve Figures

disp('==========================================================');
disp('Beveridge Curve Figures');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

%-----------------------------------------------------------------------
% Panels of Figure 2 of the paper: Inventory, Search activity and volume
%-----------------------------------------------------------------------

pos = [.05 .11 .43 .81;
       .55 .11 .43 .81];      

z1 = aggstuff(3).mu_h;
x1 = aggstuff(3).bs_weightedh;
y1 = aggstuff(3).I *100;
a1 = aggstuff(3).V *100;

z2 = z1(y1<2.1);
x2 = x1(y1<2.1);
y2 = y1(y1<2.1);
a2 = a1(y1<2.1);

% City-level aggregates (weighted by mu_h)
figure;
shade=-0.4;FS=18;
dotcolor=log(aggstuff(3).price(y1<2.1));
boundaries=[min(dotcolor) max(dotcolor)];
colormap(gray);
G=brighten(gray,shade);
G=flipud(G);
colormap(G);
caxis(boundaries);

set(gca,'FontSize',FS);
scatter(x2,y2,dotscale*400*z2,dotcolor,'filled');
xlabel('Search activity \sigma');ylabel('Inventory Share I');
axis([0 2.2 0 2.2]);
set(gca,'FontSize',FS,'YTick',[1,2]);
print('-dpdf',  [paperdir 'BevFig1.pdf']);

figure;
colormap(G);
set(gca,'FontSize',FS);
scatter(a2,y2,dotscale*400*z2,dotcolor,'filled');
xlabel('Turnover rate V');ylabel('Inventory Share I');
axis([0.1 0.4 0 2.2]);
set(gca,'FontSize',FS,'YTick',[1,2]);
print('-dpdf',  [paperdir 'BevFig2.pdf']);

% Now Within City 
% Pick SF -- Get the "number" by looking at citynames, it's 79

% Check how many segments there are
sum(aggcity(79,:))

z1 = aggstuff(1).mu_h;
x1 = aggstuff(1).bs_weightedh;
y1 = aggstuff(1).I*100;
a1 = aggstuff(1).V*100;

x2 = x1(aggcity(79,:)' == 1);
y2 = y1(aggcity(79,:)' == 1);
a2 = a1(aggcity(79,:)' == 1);
z2 = z1(aggcity(79,:)' == 1);

% City-level aggregates (weighted by mu_h)
figure;
colormap(G);
dotcolor=log(aggstuff(1).price(aggcity(79,:)' == 1));
boundaries=[min(dotcolor) max(dotcolor)]; caxis(boundaries);
set(gca,'FontSize',FS);
scatter(x2,y2,dotscale*3000*z2,dotcolor,'filled');
xlabel('Search activity \sigma');ylabel('Inventory Share I');
axis([0 8 0 2.2]);
set(gca,'FontSize',FS,'YTick',[1,2]);
print('-dpdf',  [paperdir 'BevFig3.pdf']);

figure;
colormap(G);
set(gca,'FontSize',FS);caxis(boundaries);
scatter(a2,y2,dotscale*3000*z2,dotcolor,'filled');
xlabel('Turnover rate V');ylabel('Inventory Share I');
axis([0.1 0.4 0 2.2]);
set(gca,'FontSize',FS,'YTick',[1,2]);
print('-dpdf',  [paperdir 'BevFig4.pdf']);




%%

disp('==========================================================');
disp('Figure 3 in Paper');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

diagnostics_search



%% =======================================================================
%  Exactly identified estimation exercise
%  =======================================================================

% Must preset mu_s, mu_h_calc, ThH_calc, f_J_calc, buyerT, beta_tilde_calc
% Mean buyer rate

alpha_bar = sum(mu_s(T>0)./T(T>0))/sum(mu_s(T>0));

aggmatrices      = {'eye(Nh)','aggzip','aggcity', 'aggcounty','aggbayarea'};

for agg=1:length(aggmatrices)

    aggnow = eval(aggmatrices{agg});

    % Must preset mu_s_calc, mu_h_calc, T_calc, ThH_calc, beta_tilde_calc
    
    V_calc  = aggstuff(agg).datamat(:,3);
    I_calc  = aggstuff(agg).datamat(:,1);

    T_calc = I_calc./V_calc;    
    %T_calc(T_calc==0)=mean(T_calc);
    
    mu_s_calc = aggstuff(agg).mu_s;
    mu_h_calc = aggstuff(agg).mu_h;  
    
    % For search matrix implementation
    ThH_calc        = aggstuff(agg).ThH;
    beta_tilde_calc = beta_tilde;

    % estimate eta
    eta = V_calc./(1-I_calc);

    % Estimate mu_th and mbuy ( = alpha)
    estimate_exact;

    % Results we record for each model
    resnames = {'mu_th','eta','mbuy','q','desire','speed','mu_tilde_b','desire_seg','mu_th_seg','mu_b'};
    for i=1:length(resnames)
      varnow = eval([resnames{i}]);
      models.full(agg).(resnames{i}) = varnow;
    end
    
    % For fully segmented case; same alpha_bar for each unit
    mu_th  = mu_h_calc .* (1 + alpha_bar.*V_calc);
    mbuy   = V_calc.*mu_h_calc./(mu_th-mu_h_calc);
    q      = 1   ./ (mbuy.*T_calc);  
    mhat   = mbuy .* q;
    desire = mu_th ./ mu_h_calc;
    speed  = mbuy;
    
    resnames2 = {'mu_th','eta','mbuy','q','desire','speed'};
    
    for i=1:length(resnames2)
        varnow = eval(resnames2{i});
        models.basic(agg).(resnames2{i}) = varnow;
    end
    
    % For fully segmented case; correct # of buyers
    mu_b_true = aggnow*(models.full(1).q .* aggstuff(1).mu_s);
    mu_th = mu_h_calc + mu_b_true;
    mbuy = V_calc.*mu_h_calc./(mu_th-mu_h_calc);
    q      =  1   ./ (mbuy.*T_calc);
    mhat   =  mbuy .* q;
    desire = mu_th ./ mu_h_calc;
    speed  = mbuy;
    
    resnames2 = {'mu_th','eta','mbuy','q','desire','speed'};
    for i=1:length(resnames2)
        varnow = eval(resnames2{i});
        models.matchbuyers(agg).(resnames2{i}) = varnow;
    end
    
end

%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% MATRIX THAT CALCULATES SHARE OF POPULATION OF EACH SEGMENT THAT IS MADE UP OF A TYPE-THETA PERSON
%  
%  -- Produce variable matrix_share_equilibrium_live (segment, theta)
%     Gives, for each segment, the share of owners that are of each type (each row adds up to 1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% Extract parameters from the model that we solved via "estimate_exactS14" 
mu_b_solved_segment       = models.full(1).mu_b;
mu_tilde_b_solved_segment = models.full(1).mu_tilde_b;
invshares_segment         = (ThH * mu_s);

for t = 1:size(invshares_segment,1)
    for s = 1:size(mu_s,1)
        matrix_share_equilibrium_live(s,t) = (mu_s(s) / invshares_segment(t)) * (mu_tilde_b_solved_segment(t) / mu_b_solved_segment(s)) * (ThH(t,s) == 1);
    end
end

% Share of inventory scanned
inv_share_scanned = (ThH * mu_s) / sum(mu_s);

% Average share of inventory scanned of people living in zip code
average_searcher_breadth = matrix_share_equilibrium_live * inv_share_scanned;

new_output1 = [dirroot '\model output\equilibrium_population.csv'];
new_output2 = [dirroot '\model output\equilibrium_inventory_scanned.csv'];
new_output3 = [dirroot '\model output\equilibrium_avg_inventory_scanned.csv'];

csvwrite([new_output1], matrix_share_equilibrium_live)
csvwrite([new_output2], inv_share_scanned)
csvwrite([new_output3], average_searcher_breadth)

%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Calculate Segment to Segment Flows
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% Number of buyers of type t losing home in segment s per period (since
% matrix_share_equilibrium_live rows added up to one, need to multiply by
% mu_h .

eta_solved_segment              = models.full(1).eta;
[number_segments, number_types] = size(matrix_share_equilibrium_live);
separation_flow_seg_theta       = repmat(eta_solved_segment.*mu_h,1,number_types).*matrix_share_equilibrium_live; % (segment, theta)

% Total Mass of type-theta agents losing job every period

for t = 1:size(invshares_segment,1)
    for s = 1:size(mu_s,1)
        where_do_they_find_favorite(t,s) = (mu_s(s) / invshares_segment(t)) * (ThH(t,s) == 1); 
    end
end

segment_to_segment_flows = separation_flow_seg_theta * where_do_they_find_favorite;
share_moves              = segment_to_segment_flows./sum(sum(segment_to_segment_flows));
new_output1 = [dirroot '\model output\segment_to_segment_flow.csv'];
csvwrite([new_output1], share_moves);

%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Output Popularity for zip-code level analysis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

popularity = models.full(1).desire;
new_output1 = [dirroot '\model output\popularity.csv'];
csvwrite([new_output1], popularity);


%% Top Coding of some variables for Figures

etaT=models.full(1).eta;
etaT(eta>.01)=.01;
desireT=models.full(1).desire;
desireT(desire>1.7) = 1.7;
speedT=models.full(1).speed;
speedT(speed>1)=1;


%% Consistently aggregate parameters by unit, leads to true agg pars



varnames={'eta','desire','speed','demdiff'};
%--- weights for aggregation - not normalized!
weights={'mu_h','mu_h','mu_b','mu_h'};
%--- agg unit names and formulas for aggregation matrices,
%    first must be segment!
mu_b = models.full(1).mu_b;

models.full(1).demdiff = models.full(1).mu_b./(mu_h*sum(models.full(1).mu_b)) - aggstuff(1).bs_weightedh;

for agg = 1:4;
    
    aggnow = eval(aggmatrices{agg});
    
    N_agg = size(aggnow,1);
    aggstuff(agg).N_agg = N_agg;
    
    % Form weighted aggregate for each variable
    
    for i=1:length(varnames);
        weightnow                   = eval(weights{i});
        models.true(agg).(varnames{i}) = (aggnow*(weightnow.*models.full(1).(varnames{i})))./(aggnow*weightnow);
    end;
    

end

dotscale = 30;

modnames={'true','full','basic','matchbuyers'};

%-------------------- backed out parameters vs moments for full model
vars = {'I','V','bs_weightedh'};
pars = {'eta','desire','speed'};

%% PRODUCE TABLE 4 WITH PARAMETER ESTIMATES

disp(' ');disp(' ');disp(' ');
disp('==========================================================');
disp('Table 4');
disp('==========================================================');
disp(' ');disp(' ');disp(' ');

for agg = [1,3]
    bigmatrix=[100*models.true(agg).eta models.true(agg).desire models.true(agg).speed ...\
        aggstuff(agg).I aggstuff(agg).V aggstuff(agg).bs_weightedh aggstuff(agg).logprice...
        models.true(agg).demdiff];
    
    disp(['========================== Unit = ' unitsmain{agg}]);
    
    if agg == 1
        disp('SUMMARY STATISTICS (PANEL A)');disp(' ');
        disp('     eta      desire     speed       I        V     search   logprice  demdiff');
        disp('means');
        disp(round(mean(bigmatrix),2));
        disp('vol');
        disp(round(sqrt(var(bigmatrix)),2));
        disp('Min')
        disp(round(min(bigmatrix),2))
        disp('Max')
        disp(round(max(bigmatrix),2))
        disp('q25 median q75');
        disp(round(quantile(bigmatrix,[.25 .5 .75]),2));
        
        disp(' '); disp('-------------------------------')
        disp('Differences in Desirability')
        disp('-------------------------------'); disp(' ');
        
        desire_diff = models.true(1).desire - models.matchbuyers(1).desire;
        
        disp('Mean');
        disp(round(mean(desire_diff),2));
        
        disp('q25 median q75');
        disp(round(quantile(desire_diff,[.25 .5 .75]),2))
        
        disp('Percentiles of hypothetical desirability from segmented model: q25 median q75');
        disp(quantile(models.matchbuyers(1).desire,[.25 .5 .75]))
        
    end
    
    disp(' '); disp('-------------------------------')
    disp('PANEL B: CORRELATIONS')
    disp('-------------------------------'); disp(' ');
    
    disp(['Correlations at level: ' unitsmain{agg}]);
    disp('   eta      desire      speed         I        V       search    logprice       demdiff');
    disp(round(corr(bigmatrix),2));
    
end

agg=1;
bigmatrix=[models.true(agg).eta models.true(agg).desire models.true(agg).speed ...\
           aggstuff(agg).I aggstuff(agg).V aggstuff(agg).bs_weightedh aggstuff(agg).logprice...
           models.true(agg).demdiff];

disp('Within San Francisco');
disp('   eta      desire      speed         I        V      search    logprice  demdiff');
disp('correlations');
disp(round(corr(bigmatrix(78:156,:)),2));  % seg_citiesN: Segments 78 - 156 are San Francisco