%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate the input files for the calibration of the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all; clear all;

datadir = 'Bay Area Data Files\';

a           = importdata([datadir 'searchpatterns.txt'],',',1);
ThH         = a.data(:,1:end-1);
dups        = a.data(:,end);

[Nthhere,Nh] = size(ThH);

% Empty searches?
check       = sum(ThH,2);
keep        = find(check>0);
ThH         = ThH(keep,:);
dups        = dups(keep);
Nth         = size(ThH,1);

% Segments considered
lookedat = sum(ThH,2);

beta_tilde = (dups+1)/(sum(dups)+size(dups,1));  % DUPS = Number of people per query
numqueries = sum(dups);

%% Prepare to eliminate 'questionable' queries which cover very large price ranges
%     Note: This switch does not 

drop_questionable = 1;

if drop_questionable == 1
    
    % Read median price
    b = importdata([datadir 'segments.txt'],',',1);
    medprice = (b.data(:,8));
    
    % Patch NaN
    bad           = isnan(medprice);
    avg           = mean(medprice(~bad));
    medprice(bad) = avg;
    
    pricemat = ThH.*repmat(medprice',Nth,1);
    maxprice = max(pricemat,[],2);
    minprice = zeros(Nth,1);
    
    for j=1:Nth
        minprice(j) =  min(pricemat(j,pricemat(j,:)>0));
    end
    
    rangeprice = maxprice - minprice;
    
    % Questionable searches: price range exceeds 95th percentile of min price
    rangebounds_min = 1e3*[600 600 600 600 650 1000 1000 1040 1320 2500*ones(1,20)]';
    
    mincoarse    = floor(minprice/1e5)+1;
    questionable = (rangeprice > rangebounds_min(mincoarse));
    
    selq       = logical(questionable);
    selnq      = ~selq;
    ThH        = ThH(selnq,:);
    
    
    beta_tilde = beta_tilde(selnq)/sum(beta_tilde(selnq));
    numqueries = sum(dups(selnq))+size(dups(selnq),1);
    
    ThH(762,420)=1;  % When dropping the broad queries, a single small segment does not have a single query covering it. 
                     % Here we include it in a query that covers neighboring areas. Results are robust to dropping it.                    
    
end

%% Report Stats on Search Queries

disp('Number of Unique Search Queries')
size(squeeze(squeeze(ThH(:,1))))

disp('Number of Unique Searchers')
sum(numqueries)

save ThH_matrix ThH beta_tilde numqueries
