

%% Price implications

%=====================================================================
% run "estimate.m" up to estimation cell, then run this script to
%   get price results & make Figure 7 of paper
%======================================================================

% pick additional parameter: interest rate
r=.01/12;

% not sensitive to r
alpha = models.full(1).eta ./ (r + 1./T + models.full(1).eta);

% cost c = kk * p, with kk proportional to price
%   choose kk so that c * T = .06 p in median market
kk = .06 ./ T;


price_nofric = price.* (1 + alpha.*kk/r)./(1-alpha);
discount = 1 - price./price_nofric;

% ----------- Price & discount

figure
subplot(2,1,1);
hold on;
colormap cool;
scatter(price/1000,price_nofric/1000,3e6*mu_h.*V,log(tsmeans(:,2)),'filled');
xlabel('price');ylabel('frictionless price');

subplot(2,1,2);
hold on;
colormap cool;
scatter(price/1000,discount*100,3e6*mu_h.*V,log(tsmeans(:,2)),'filled');
xlabel('price');ylabel('discount');

FS=10;

figure;
subplot(1,2,1);

hold on;
colormap cool; set(gca,'FontSize', FS); hold on;
scatter(log(price),100*discount,msize,discount,'filled');
xlabel('Price, $000');ylabel('Frictional discount, %');
set(gca,'Xtick',[log(1e5),log(2e5),log(5e5),log(1e6)]);
set(gca,'Xticklabel',[100 200 500 1000]);
%plot(plotratio,plotratio,'k--','LineWidth',1);
axis([min(log(price)) max(log(price)) 0 50]);

subplot(1,2,2);
set(gca,'Position',[.51 .11 .47 .81])
%         hold on;
%         bayarea_sub;
%         colormap cool;
%         bayareaextras_dots;
%         scatterm(lat,lon,30,quantiles_array{mm}(:,2)/sum(marketcomps(:,mm)),'filled');



var_color = 'discount';

var_box = [min(eval(var_color)) max(eval(var_color))];
varval = eval(var_color);

bayarea_sub
hold on;
cc = colormap(cool);


% set of points
scatterm(lat_seg,lon_seg,30,(varval - var_box(1))/(var_box(2)-var_box(1)),'filled');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TOP-CODE DISCOUNTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


disp('mean & quantiles of discount');
mean(discount)
quantile(discount,[.1 .25 .5 .75 .9])



discountT = discount;
cut=.36;
discountT(discount>cut) = cut;


shade=-0.4;
colormap(gray);
G=brighten(gray,shade);
G=flipud(G);

figure;
subplot(1,2,1);


colormap(G);

hold on;
set(gca,'FontSize', FS); hold on;
scatter(log(price),100*discountT,msize,discountT,'filled');
xlabel('Price, $000');ylabel('Frictional discount, %');
set(gca,'Xtick',[log(1e5),log(2e5),log(5e5),log(1e6)]);

set(gca,'Xticklabel',[100 200 500 1000]);
axis([min(log(price)) max(log(price)) -0.4 100*cut]);

subplot(1,2,2);
set(gca,'Position',[.51 .11 .47 .81])

var_color = 'discountT';

var_box = [min(eval(var_color)) max(eval(var_color))];
varval = eval(var_color);

bayarea_sub
hold on;
cc = colormap(G);

% set of points
scatterm(lat_seg,lon_seg,25,(varval - var_box(1))/(var_box(2)-var_box(1)),'filled');

print('-dpdf',[paperdir 'Illiquidity.pdf']);
